==> haskell-hls-module-name-plugin-2.0.0.0-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-module-name-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-module-name-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-module-name-plugin-2.0.0.0-6s8mLmJHwwf2gRwpW3XOIR
key:                  hls-module-name-plugin-2.0.0.0-6s8mLmJHwwf2gRwpW3XOIR
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Module name plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  f047f5557b15a423d36e6a16df0a915e
exposed:              True
exposed-modules:      Ide.Plugin.ModuleName
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-module-name-plugin-2.0.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-module-name-plugin-2.0.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-module-name-plugin-2.0.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-module-name-plugin
hs-libraries:         HShls-module-name-plugin-2.0.0.0-6s8mLmJHwwf2gRwpW3XOIR
depends:
    aeson-2.1.2.1-7NKMY9av0haL3nHVKphSJj base-4.17.2.1
    directory-1.3.7.1 filepath-1.4.2.2
    ghcide-2.0.0.0-6lLAsA4Lr7h3wkdpkTQreJ
    hls-plugin-api-2.0.0.0-I1zf9n2yEAFBhjm47QUlP3
    lsp-1.6.0.0-LOrWurGUfcm1ZXl1RcyPxv text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX

haddock-interfaces:
    /usr/share/doc/haskell-hls-module-name-plugin/html/hls-module-name-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-module-name-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-module-name-plugin-2.0.0.0-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-module-name-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-module-name-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-module-name-plugin-2.0.0.0-9UhWk0b4S5S4BrqgGSyWyH
key:                  hls-module-name-plugin-2.0.0.0-9UhWk0b4S5S4BrqgGSyWyH
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Module name plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  05281ad06ec905dba7f8ae60f2177ab0
exposed:              True
exposed-modules:      Ide.Plugin.ModuleName
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-module-name-plugin-2.0.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-module-name-plugin-2.0.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-module-name-plugin-2.0.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-module-name-plugin
hs-libraries:         HShls-module-name-plugin-2.0.0.0-9UhWk0b4S5S4BrqgGSyWyH
depends:
    aeson-2.1.2.1-7NKMY9av0haL3nHVKphSJj base-4.17.2.1
    directory-1.3.7.1 filepath-1.4.2.2
    ghcide-2.0.0.0-EDmIPFLm0lveZyxxxhQXq
    hls-plugin-api-2.0.0.0-LgSw2LvZrUpJ7ID7iA1h02
    lsp-1.6.0.0-LOrWurGUfcm1ZXl1RcyPxv text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX

haddock-interfaces:
    /usr/share/doc/haskell-hls-module-name-plugin/html/hls-module-name-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-module-name-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
